## 9.0.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 9.0.2 (2022-01-07)

Pillow: Image fixes (#6848)

* Fix return type of `Image.transform()`.
* Add animation attributes to `Image`.

## 9.0.0 (2022-01-05)

Upgrade stubs to Pillow 9 (#6795)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 8.3.11 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 8.3.10 (2021-12-23)

Remove PIL.__main__ (#6665)

## 8.3.9 (2021-12-21)

correct border= and fill= kwargs for ImageOps.expand (#6641)

## 8.3.8 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 8.3.7 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 8.3.6 (2021-10-11)

Annotate PIL.ImageColor (#6151)

## 8.3.5 (2021-10-11)

Color arguments also take (r,g,b,a) tuples  (#6148)

## 8.3.4 (2021-09-06)

Fix type of stroke_width parameter in Pillow's ImageDraw.*text* functions (#6008)

